==> pymatrix-rain-1.2.0.tar.gz: pymatrix-rain-1.2.0/README.md <==
# pymatrix-rain
Matrix rain effect using python 3 and curses.

### How to Download
 >pip install pymatrix-rain
 
 To run: pymatrix-rain


##### NOTE:

> not tested on Windows or Mac


###  Commands
- **<kbd>Q</kbd>** or **<kbd>q</kbd>** = *Quits*
- **<kbd>b</kbd>** = *Bold on*
- **<kbd>B</kbd>** = *Bold all*
- **<kbd>n</kbd>** = *Bold off*
- **<kbd>0-9</kbd>** = *Delay speed 0-Fast, 4-Default, 9-Slow*
- **<kbd>a</kbd>** = *Asynchronous like scrolling*
- **<kbd>m</kbd>** = *Multiple color mode*
- **<kbd>M</kbd>** = *Multiple random color mode*
- **<kbd>d</kbd>** = *Reset to default*
- **<kbd>c</kbd>** = *Cycle through colors automatically*
- **<kbd>l</kbd>** = *Toggle double space lines*
- **<kbd>e</kbd>** = *Toggle extended characters*
- **<kbd>E</kbd>** = *Only extended characters if on*
- **<kbd>z</kbd>** = *Zero and One Mode On*
- **<kbd>Z</kbd>** = *Zero and One Mode Off*
- **<kbd>f</kbd>** = *Freeze and unfreeze the matrix. Can still use **<kbd>Q</kbd>** to quit.*
- **<kbd>v</kbd>** = *Toggle the matrix to scroll up*
- **<kbd>W</kbd>** = *Toggle do not clear screen*
- **<kbd>w</kbd>** = *Clear the screen, wait 2 seconds and start*
- **<kbd>j</kbd>** = *Toggle italic text*
- **<kbd>shift 0-9</kbd>** = *Cycle color delay*

##### Rain Colors
- **<kbd>r</kbd>** = Red
- **<kbd>t</kbd>** = Green
- **<kbd>y</kbd>** = Blue
- **<kbd>u</kbd>** = Yellow
- **<kbd>i</kbd>** = Magenta
- **<kbd>o</kbd>** = Cyan
- **<kbd>p</kbd>** = White
- **<kbd>[</kbd>** = Black

##### Lead Char Color
- **<kbd>R</kbd>** = Red
- **<kbd>T</kbd>** = Green
- **<kbd>Y</kbd>** = Blue
- **<kbd>U</kbd>** = Yellow
- **<kbd>I</kbd>** = Magenta
- **<kbd>O</kbd>** = Cyan
- **<kbd>P</kbd>** = White
- **<kbd>{</kbd>** = Black

##### Background Colors
- **<kbd>ctrl-r</kbd>** = Red
- **<kbd>ctrl-t</kbd>** = Green
- **<kbd>ctrl-y</kbd>** = Blue
- **<kbd>ctrl-u</kbd>** = Yellow
- **<kbd>ctrl-i</kbd>** = Magenta
- **<kbd>ctrl-o</kbd>** = Cyan
- **<kbd>ctrl-p</kbd>** = White
- **<kbd>ctrl-[</kbd>** = Black

## Screen Shots
![matrix1.png](https://i.fluffy.cc/Vs2ZW5PBdM0QXv7Ljz3LDV7JCg2LJBJK.png)

![matrix2.png](https://i.fluffy.cc/LWwpSxJldKBBVlC260Zc7T5CRg7JN303.png)

![matrix3.png](https://i.fluffy.cc/K0MNwrm4KC69NZRQm1k3JsR9j1FqxjWm.png)

![matrix4.png](https://i.fluffy.cc/h582RvNQxqcsX5029wcK9q0v2kBPcRMd.png)

Scrolling Up
![matrix5.png](https://i.fluffy.cc/q7xjhc011J6N5nP53dDKrnnJNX7Qp5t3.png)

Zero and One Mode
![matrix6.png](https://i.fluffy.cc/JdRwzdWxltVxc80RDGg7BDB41hZMFmNN.png)

Extended Characters
![matrix7.png](https://i.fluffy.cc/P20WlgFZwNsdCLDxfnmbSPcKCZKnlHS6.png)

Italic Mode
![matrix8.png](https://i.fluffy.cc/5jBjfXT0c7Vjl0gX1xkMT7nq3wXNwkNV.png)

==> pymatrix-rain-1.3.0.tar.gz: pymatrix-rain-1.3.0/README.md <==
# pymatrix-rain
Matrix rain effect using python 3 and curses.

### How to Download
 >pip install pymatrix-rain
 
 To run: pymatrix-rain


##### NOTE:

> not tested on Windows or Mac


###  Commands
- **<kbd>Q</kbd>** or **<kbd>q</kbd>** = *Quits*
- **<kbd>b</kbd>** = *Bold on*
- **<kbd>B</kbd>** = *Bold all*
- **<kbd>n</kbd>** = *Bold off*
- **<kbd>0-9</kbd>** = *Delay speed 0-Fast, 4-Default, 9-Slow*
- **<kbd>a</kbd>** = *Asynchronous like scrolling (normal scrolling only)*
- **<kbd>m</kbd>** = *Multiple color mode*
- **<kbd>M</kbd>** = *Multiple random color mode  (normal scrolling only)*
- **<kbd>d</kbd>** = *Reset to default*
- **<kbd>c</kbd>** = *Cycle through colors automatically*
- **<kbd>l</kbd>** = *Toggle double space lines*
- **<kbd>e</kbd>** = *Toggle extended characters*
- **<kbd>E</kbd>** = *Only extended characters if on*
- **<kbd>k</kbd>** = *Half width Katakana characters like those from the movies. If the correct font is installed.*
- **<kbd>K</kbd>** = *Half width Katakana characters only*
- **<kbd>z</kbd>** = *Zero and One Mode On*
- **<kbd>Z</kbd>** = *Zero and One Mode Off*
- **<kbd>f</kbd>** = *Freeze and unfreeze the matrix. Can still use **<kbd>Q</kbd>** to quit.*
- **<kbd>v</kbd>** = *Toggle the matrix to scroll up*
- **<kbd>W</kbd>** = *Toggle do not clear screen  (normal scrolling only)*
- **<kbd>w</kbd>** = *Clear the screen, wait 2 seconds and start*
- **<kbd>j</kbd>** = *Toggle italic text*
- **<kbd>s</kbd>** = *Toggle old style matrix scrolling (down only)*
- **<kbd>up arrow</kbd>** = *Matrix scrolling up*
- **<kbd>down arrow</kbd>** = *Matrix scrolling down (Default)*
- **<kbd>left arrow</kbd>** = *Matrix scrolls from right to left*
- **<kbd>right arrow</kbd>** = *Matrix scrolls from left to right*
- **<kbd>shift 0-9</kbd>** = *Cycle color delay*

##### Rain Colors
- **<kbd>r</kbd>** = Red
- **<kbd>t</kbd>** = Green
- **<kbd>y</kbd>** = Blue
- **<kbd>u</kbd>** = Yellow
- **<kbd>i</kbd>** = Magenta
- **<kbd>o</kbd>** = Cyan
- **<kbd>p</kbd>** = White
- **<kbd>[</kbd>** = Black

##### Lead Char Color
- **<kbd>R</kbd>** = Red
- **<kbd>T</kbd>** = Green
- **<kbd>Y</kbd>** = Blue
- **<kbd>U</kbd>** = Yellow
- **<kbd>I</kbd>** = Magenta
- **<kbd>O</kbd>** = Cyan
- **<kbd>P</kbd>** = White
- **<kbd>{</kbd>** = Black

##### Background Colors
- **<kbd>ctrl-r</kbd>** = Red
- **<kbd>ctrl-t</kbd>** = Green
- **<kbd>ctrl-y</kbd>** = Blue
- **<kbd>ctrl-u</kbd>** = Yellow
- **<kbd>ctrl-i</kbd>** = Magenta
- **<kbd>ctrl-o</kbd>** = Cyan
- **<kbd>ctrl-p</kbd>** = White
- **<kbd>ctrl-[</kbd>** = Black

## Screen Shots
![matrix1.png](https://i.fluffy.cc/Vs2ZW5PBdM0QXv7Ljz3LDV7JCg2LJBJK.png)

![matrix2.png](https://i.fluffy.cc/LWwpSxJldKBBVlC260Zc7T5CRg7JN303.png)

![matrix3.png](https://i.fluffy.cc/K0MNwrm4KC69NZRQm1k3JsR9j1FqxjWm.png)

![matrix4.png](https://i.fluffy.cc/h582RvNQxqcsX5029wcK9q0v2kBPcRMd.png)

Scrolling Up
![matrix5.png](https://i.fluffy.cc/q7xjhc011J6N5nP53dDKrnnJNX7Qp5t3.png)

Scrolling right
![ScrollRight](https://i.fluffy.cc/7pTmzLLgr2gXl2qhQbr5HTNvQPsMZgCZ.png)

Katakana Characters
![KatakanaCharacters](https://i.fluffy.cc/Kq5gmgXR6zcNzMCjchP3qJ9BFv89d5zd.png)

Zero and One Mode
![matrix6.png](https://i.fluffy.cc/JdRwzdWxltVxc80RDGg7BDB41hZMFmNN.png)

Extended Characters
![matrix7.png](https://i.fluffy.cc/P20WlgFZwNsdCLDxfnmbSPcKCZKnlHS6.png)

Italic Mode
![matrix8.png](https://i.fluffy.cc/5jBjfXT0c7Vjl0gX1xkMT7nq3wXNwkNV.png)
